@@ -1,7 +1,8 @@
 #ifndef NSTD_ALLOC_ALLOC_H_INCLUDED
 #define NSTD_ALLOC_ALLOC_H_INCLUDED
 #include "../core/def.h"
-#ifdef __cplusplus
+#include "../nstd.h"
+#ifdef NSTDCPP
 extern "C"
 {
 #endif
@@ -23,8 +24,8 @@ NSTDAPI NSTDAny nstd_alloc_allocate_zeroed(const NSTDUSize size);
 ///     `NSTDAny *const ptr` - Pointer to the memory block.
 ///     `const NSTDUSize size` - The current size of the memory block.
 ///     `const NSTDUSize new_size` - The new size of the memory block.
-/// Returns: `NSTDInt32 errc` - Nonzero on error.
-NSTDAPI NSTDInt32 nstd_alloc_reallocate(
+/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+NSTDAPI NSTDErrorCode nstd_alloc_reallocate(
     NSTDAny *const ptr,
     const NSTDUSize size,
     const NSTDUSize new_size);
@@ -33,10 +34,10 @@ NSTDAPI NSTDInt32 nstd_alloc_reallocate(
 /// Parameters:
 ///     `NSTDAny *const ptr` - Pointer to the memory block.
 ///     `const NSTDUSize size` - Number of bytes to deallocate.
-/// Returns: `NSTDInt32 errc` - Nonzero on error.
-NSTDAPI NSTDInt32 nstd_alloc_deallocate(NSTDAny *const ptr, const NSTDUSize size);
+/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+NSTDAPI NSTDErrorCode nstd_alloc_deallocate(NSTDAny *const ptr, const NSTDUSize size);
 
-#ifdef __cplusplus
+#ifdef NSTDCPP
 }
 #endif
 #endif
