@@ -1,7 +1,8 @@
 #ifndef NSTD_TIME_H_INCLUDED
 #define NSTD_TIME_H_INCLUDED
 #include "core/def.h"
-#ifdef __cplusplus
+#include "nstd.h"
+#ifdef NSTDCPP
 extern "C"
 {
 #endif
@@ -9,18 +10,25 @@ extern "C"
 /// Represents a datetime object.
 typedef struct
 {
-    int year;
-    unsigned int month;
-    unsigned int day;
-    unsigned int hour;
-    unsigned int minute;
-    unsigned int second;
-    unsigned int nanosecond;
+    /// The year.
+    NSTDInt32 year;
+    /// The month.
+    NSTDUInt32 month;
+    /// The day.
+    NSTDUInt32 day;
+    /// The hour.
+    NSTDUInt32 hour;
+    /// The minute.
+    NSTDUInt32 minute;
+    /// The second.
+    NSTDUInt32 second;
+    /// The nanosecond.
+    NSTDUInt32 nanosecond;
 } NSTDDateTime;
 
 /// Gets the time in seconds since the unix epoch.
-/// Returns: `double time` - Number of seconds since unix epoch.
-NSTDAPI double nstd_time_time();
+/// Returns: `NSTDFloat64 time` - Number of seconds since unix epoch.
+NSTDAPI NSTDFloat64 nstd_time_time();
 
 /// Gets an `NSTDDateTime` object representing the local time it was created.
 /// Returns: `NSTDDateTime now` - Now represented as a `NSTDDateTime` object.
@@ -30,7 +38,7 @@ NSTDAPI NSTDDateTime nstd_time_now();
 /// Returns: `NSTDDateTime now` - UTC now represented as a `NSTDDateTime` object.
 NSTDAPI NSTDDateTime nstd_time_utc_now();
 
-#ifdef __cplusplus
+#ifdef NSTDCPP
 }
 #endif
 #endif
